#
# spec file for package fastfetch
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fastfetch
Version:        2.1.2
Release:        1.1
Summary:        Neofetch-like tool written in C
License:        MIT
Group:          Productivity/Text/Utilities
URL:            https://github.com/LinusDierheimer/fastfetch
Source:         https://github.com/LinusDierheimer/fastfetch/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  Mesa-devel
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  opencl-headers
BuildRequires:  vulkan-headers
BuildRequires:  pkgconfig(ImageMagick)
BuildRequires:  pkgconfig(chafa)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libpci)
BuildRequires:  pkgconfig(libxfconf-0)
BuildRequires:  pkgconfig(ocl-icd)
BuildRequires:  pkgconfig(rpm)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(zlib)
Recommends:     ImageMagick
Recommends:     Mesa
Recommends:     chafa
Recommends:     dbus-1
Recommends:     dconf
Recommends:     glib2-tools
Recommends:     pciutils
Recommends:     rpm
Recommends:     sqlite3
Recommends:     vulkan-tools
Recommends:     xfconf
Recommends:     xrandr
Recommends:     zlib

%description
Fastfetch is a neofetch-like tool for fetching system information and displaying them in a pretty way.
It is written in pure c, with performance and customizability in mind. Currently Linux, Android, FreeBSD,
MacOS and Windows 7+ are supported.

%prep
%setup -q

sed -i "s|\#\!\/usr\/bin\/env bash||g" completions/bash

%build
%cmake
%cmake_build

%install
%cmake_install

%files
%license LICENSE
%doc README.md CHANGELOG.md
%{_bindir}/flashfetch
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/bash-completion/

%changelog
* Mon Oct 30 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Declare new build deps gcc and gcc-c++
- Update to version 2.1.2. Changes listed after 2.0.5:
    [#] 2.1.2
    Bugfixes:
  * Fix icon detection on Windows. It shows enabled system icons in desktop (`This PC`, `Recycle Bin`, etc) (Icon, Windows)
  * Fix compatibility with ddcutil 2.0 (Brightness, Linux)
  * Fix a compile warning (CPUUsage, FreeBSD)
    [#] 2.1.1
    Features:
  * Support opkg (Packages, Linux)
  * Support GNOME Console terminal version and font detection (Terminal, Linux)
  * Add `--cpu-freq-ndigits` to set number of digits for CPU frequency (CPU)
  * New module to detect physical disk I/O usage (DiskIO)
  * Add `--cpuusage-separate` to display CPU usage per CPU logical core
  * Add `--brightness-ddcci-sleep` to set the sleep times (in ms) when sending DDC/CI requests (Brightness, #580)
    Bugfixes:
  * Fix possible crashes on Windows 7 (Disk, Windows)
  * Fix possible crashes caused by uninitialized strings (Users, Windows)
  * Improve support of `--help *-format` and several bugs are found and fixed
  * Don't incorrectly print `No active sound devices found` when using a non-controllable sound device (Sound, macOS)
  * Fix implementation processes counting (Processes, Linux)
  * Work around a issue that SSID cannot be detected on macOS Sonoma (Wifi, macOS)
    Logo:
  * Add Chimera Linux
  * Add EndeavourSmall
  * Add Xenia
    [#] 2.1.0
    This release introduces a new output format: JSON result
    Changes:
  * Users module detects and prints user login time by default. Specifying `--users-compact` to disable it
  * Fastfetch now requires yyjson 0.8.0 or later, which is embeded in fastfetch source tree. If you build fastfetch with `-DENABLE_SYSTEM_YYJSON` cmake option, you must upgrade your yyjson package
  * Reduced information supported by `--terminal-format`, `--shell-format`
  * Some config presets (`devinfo` and `verbose`) are obseleted and removed. They are barely maintained and can be replaced with `--format json` now.
  * Custom strings in `--module-key` and `--module-format` are no longer trimmed.
  * `/boot` is hidden by default (FreeBSD, Disk)
    Features:
  * Add `--format json`, which prints system information as JSON format
  * Add fast path for xfce4 version detection (DE, FreeBSD)
  * Support contour terminal version and font detection (Terminal / TerminalFont)
  * Support `kitty-direct` / `iterm` without specifying logo width / height. Note: in this case, the entre screen will be cleared.
  * Support new flag `--logo-separate`. If true, print modules at bottom of the logo
  * Support Apple Silicon CPU frequency detection (CPU, macOS)
  * Support user login time detection (Users)
  * Support winget package manager detection, guarded behind `--allow-slow-operations` (Packages, Windows)
  * Print monitor type (built-in or external) (Display)
  * Support full GPU detection in WSL (Linux, GPU)
  * Add `--module-key " "` as a special case for hiding keys
  * Support `--title-format`. See `fastfetch --help title-format` for detail
  * Support `--colors-key` (Colors)
  * Add `-c` as a shortcut of `--load-config`. Note it was used as the shortcut of `--color` before 2.0.5
  * Support Windows Service Pack version detection (Kernel, Windows)
  * Support Debian point releases detection (OS, Linux)
  * Add new module `NetIO` which prints network throughput (usage) of specified interface. Note this module costs about 1 second to finish.
  * Use `lscpu` to detect CPU name for ARM CPUs (CPU, Linux)
    Bugfixes:
  * Fix fastfetch hanging in specific environment (#561)
  * Fix short read when reading from stdin (Logo)
  * Fix `poll() timeout or failed` error when image is very large (Logo)
  * Fix Termux Monet terminal version detection (Terminal)
  * Fix zpool volumes detection (Disk, Linux)
  * Fix external volumes detection (Disk, Linux)
  * Fix snap package number detection on systems other than Ubuntu (Packages, Linux)
  * Fix dpkg / apt package number detection (Packages, Linux)
  * Fix bluetooth mac address detection (Bluetooth, Windows)
    Logo:
  * Add Afterglow
  * Add Elbrus
  * Update EvolutionOS
  * Update AOSC OS
  * Update Ubuntu_old
  * Update Windows 11_small
  * Add Amazon Linux
  * Add LainOS
  * Fix colors of Slackware
* Mon Sep 18 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.0.5:
  * Bugfixes:
  - Fix segfault when using libxrandr (#544, Display, Linux)
  - Don't print 0px (#544, Cursor)
  * Features:
  - Add option --disk-use-available (#543)
  - Add option --disk-show-readonly
- Removed config.conf to fix build
* Tue Aug 22 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 2.0.1:
  * Changes:
  - Unescape strings only when parsing .conf files
  - Previously: $ NO_CONFIG=1 fastfetch --os-key \\\\ -s os -l none prints \: *.
    Note the backslashs are unescaped twice (once by shell and once by fastfetch).
  - Now: $ NO_CONFIG=1 fastfetch --os-key \\\\ -s os -l none prints \\: *
  - Remove option shortcut -c (alias of --color), which is more commonly used as alias of --config
  - Rename --recache to --logo-recache (which is used for regenerate image logo cache). Remove option shortcut -r (alias of --recache).
  - Detecting brightness of external displays with DDC/CI is no longer guarded behind --allow-slow-operations (Brightness)
  * Features:
  - Add --key-width for aligning the left edge of values, supported both for global --key-width and specific module --module-key-width
  - Add --bar-char-elapsed, --bar-char-total, --bar-width and --bar-border options
  - Add CMake option ENABLE_SYSTEM_YYJSON, which allow building fastfetch with system-provided yyjson (for package managers)
  - Add new module Version, which prints fastfetch version (like fastfetch --version)
  * Bugfixes:
  - Fix label detection. Use --disk-key 'Disk ({2})' to display it (Disk, Linux)
  - Fix some module options were not inited
  - Fix terminal version and font detection on NixOS (Terminal, Linux)
* Fri Jul 21 2023 Dirk Müller <dmueller@suse.com>
- update to 1.12.2:
  * Support terminator terminal version detection (Linux,
    Terminal)
  * Support `pkgtool` package manager detection (Linux, Packages)
  * Support `Far` shell version detection (Windows, Shell)
  * Fix ConEmu terminal detection in some special cases (Windows,
    Terminal, #488)
  * Fix incorrect Host on M2 Mac Studio with M2 Max CPU (macOS,
    Host, #490)
  * Support KDE / LXQT / MATE / Cinnamon wallpaper detection
    (Wallpaper, Linux)
  * Support QTerminal version & terminal font detection
  * Support MATE Terminal version & terminal font detection
  * Set `--pipe true` automatically if stdout is not a tty
  * Detect new macs released on WWDC 2023 (macOS, Host)
  * Count cached memory as free memory (FreeBSD, Memory)
  * Support sound detection (FreeBSD, Sound)
  * Fix `--logo-padding-left` doesn't work when `--logo-padding-
    top` is set (Logo)
  * Fix KDE version detection on Fedora (DE)
  * Include limits.h when needed (Linux, #472)
  * Fix Windows drives detection in WSL (Linux, Disk)
  * Fix crash on newer wayland desktops (Linux, Display, #477)
* Mon Jun 12 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.11.3:
  Features:
  * Support display name, type, rotation detection on Wayland (Linux, Display)
  * Print more useful display name instead of intel_backlight (Linux, Brightness)
  * Icons module supports Windows (Windows, Icons)
  * Add Wallpaper module which shows the current wallpaper image path
  * Add mac address detection --localip-show-mac (LocalIP, #451)
  Bugfixes:
  * Fix Gnome version detection on Fedora (DE)
  * Fix Windows drives detection in WSL (Disk)
  * Fix a segfault bug, regression of 1.11.1
  Changes:
  * In order to make Icons module consistant between different platforms,
  - -icons-format no longer supports individual GTK / QT icon params.
  * --theme-format no longer supports individual GTK / plasma theme params.
  * --local-ip-* and --public-ip-* have been changed to --localip-* and --publicip-*
  * --localip-compact-type is no longer supported. Fastfetch now display IPs as
  - -localip-compat-type multiline by default, with --local-compact true can be set as an alias of --localip-compact-type oneline
  * --localip-v6first is no longer supported.
* Wed May 17 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Move configuration files based on openSUSE distribution.
* Wed May 17 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.11.0:
  * Support linuxbrew
  * Support foot terminal
  * Support cursor size detection on Windows
  * Support cursor detection on macOS
  * Support display name, display type and decimal refresh rate detection
  * Support --display-compact-type to display multiple resolutions in one line
  * Support flatpak-user
  * Support --gpu-force-vulkan to force using vulkan to detect GPUs, which support video memory usage detection with --allow-slow-operations
  * Fix date time format
  * Fix compiling with musl
  * Don't exit if libpci is failed to init
  * Names of most well-known gamepads are correctly printed instead of Wireless Controller on Windows
  * Small update for nobara logo
* Sat Mar  4 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.10.3:
  * Fix uninitialized variables (GPU, Windows)
  * Fix compiling errors (Windows)
  * Improve performance (WmTheme amd Font, Windows and macOS)
  * Enable nonblocking public-ip / weather detection (Android)
* Thu Feb  2 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.9.1:
  * Fix builds on s390x (@jonathanspw, #402)
  * Fix zero refresh rate on some monitors (macOS)
  * Fix default formatting of Wifi module
* Mon Jan 23 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.9.0
  * fastfetch no longer creates a sample config file silently. Use --gen-config to generate one.
  * fastfetch now search for user config file in the order of fastfetch --list-config-paths
  * Unknown disks are hidden by default.
  * Resolution module is renamed to Display.
  * new options: --logo-padding-top, --list-config-paths, --list-data-paths, --gpu-hide-integrated, --gpu-hide-discrete
  * Raw image file as logo support
  * Add Brightness, Wifi module support
  * Disk name support for Linux
  * Fix rpm package count detection
  * Fix cpu temp detection
* Wed Jan 18 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.8.2. Changes since then to this version:
  * 1.8.2:
  - Fix memleaks Users module (Windows)
  - Fix shell detection when installed with scoop (Windows)
  - Don't use libcJSON as wlanapi's dll name (Windows)
  - Align artifact names to other platforms (Windows)
  * 1.8.1:
  - Bios / Board / Chassis modules are splitted against Host module for performance reasons
  - Caching is removed. Option --nocache is removed accordingly
  - Windows (7 and newer) is officially and fully supported
  - FreeBSD support is improved greatly (Bios, Cpu Temp, Cpu Usage, Disk, Host, Processes, Swap, Terminal / Shell, Uptime)
  - Adds a new flag --stat, which prints time usage for individual modules
  - Adds Wifi module which supports Windows and macOS
  - Adds data source option for logo printing
  - Detects Homebrew Cellar and Cask seperately
  - Detects WSL version
  - Detects disk based on mount point
  - Exposes more chafa configs
  - Improves performance for Cpu Usage, Public IP, Weather modules
  - Improves performance for Kitty image protocol when both image width / height specified
  - Improves performance for large file loading
  - Improves performance for macOS WM and Host detection
  - Improves shell and terminal detection on macOS
  - Supports Deepin Terminal terminal font
  - Supports GPU detection on Android
  - Supports Kitty Terminal terminal font
  - Supports bar output for percentage values
  - Supports Bios module on macOS
  - Supports eopkg package manager detection
  - Supports iTerm image logo protocol
  - Supports image logo printing on macOS
  - Supports tcsh version detection
  - Vulkan module on macOS no longer requires vulkan-loader to work
  - Fixes disk size detection on 32bit Linux (#337)
  - Fixes cpu freq detection in WSL
  - Fixes internal bug of FFstrbuf
  - Fixes some memory leaks
  - Fixes segfault if 0 is given as argument index
  - Lots of code refactors
  - Added new logos:
  * Alpine
  * CRUX
  * EndeavourOS
  * Enso
  * Garuda small
  * Nobara
  * OpenMandriva
  * Parabola GNU/Linux-libre
  * Rocky
  * Rosa
  * Solus
  * Univalent
  * Vanilla OS
* Wed Dec  7 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for fastfetch 1.7.5
